@@ -5,8 +5,8 @@
 import time
 from urllib.parse import quote_plus as url_quote
 import yaml
-from src.DataExtractionPackage.controller.GenericController import GenericController
-from src.DataExtractionPackage.controller.Access_Token import AccessToken
+from controller.GenericController import GenericController
+from controller.Access_Token import AccessToken
 from sqlalchemy import create_engine
 import sqlalchemy
 from datetime import datetime
@@ -549,6 +549,6 @@ class MainClass:
 if __name__ == "__main__":
     # Run main class
 
-    main = MainClass("../../prod_config.yml")
+    main = MainClass("prod_config.yml")
     main.run()
     # mainClass = MainClass("")
