@@ -5,8 +5,8 @@
 import time
 from urllib.parse import quote_plus as url_quote
 import yaml
-from DataExtractionPackage.controller.GenericController import GenericController
-from DataExtractionPackage.controller.Access_Token import AccessToken
+from src.DataExtractionPackage.controller.GenericController import GenericController
+from src.DataExtractionPackage.controller.Access_Token import AccessToken
 from sqlalchemy import create_engine
 import sqlalchemy
 from datetime import datetime
@@ -545,3 +545,4 @@ class SetupApis:
         )
         return users_controller
 
+
